@@ -1,7 +1,7 @@
 import logging
 import shutil
 from pathlib import Path
-from typing import Union
+from typing import Dict, Union
 
 import pkg_resources
 from jinja2 import Environment, PackageLoader, select_autoescape
@@ -15,23 +15,38 @@ class HtmlNotionProcessor:
     def __init__(self, notion_client: NotionClient, output_folder: Union[str, Path]):
         self.notion_client = notion_client
         self.output_folder = Path(output_folder)
-        env = Environment(
+        self.env = Environment(
             loader=PackageLoader("nprompter", package_path="web/templates"), autoescape=select_autoescape()
         )
         self.assets_folder = Path(pkg_resources.resource_filename("nprompter", "web/assets/"))
-        self.script_template = env.get_template("script.html")
-        self.index_template = env.get_template("index.html")
+        self.script_template = self.env.get_template("script.html")
+        self.index_template = self.env.get_template("index.html")
         self.logger = logging.getLogger("NotionProcessor")
+        self.custom_css = []
 
-    def prepare_folder(self):
+    def prepare_folder(self, configuration: Dict):
         if not self.output_folder.exists():
             self.output_folder.mkdir(parents=True)
+
+        js_template = self.env.get_template("script.js")
+        css_template = self.env.get_template("nprompter.css")
+
+        with open(self.output_folder / "script.js", "w", encoding="utf8") as writeable:
+            writeable.write(js_template.render(**configuration))
+
+        with open(self.output_folder / "nprompter.css", "w", encoding="utf8") as writeable:
+            writeable.write(css_template.render(**configuration))
+
         shutil.copytree(self.assets_folder, self.output_folder, dirs_exist_ok=True)
 
+    def add_extra_style(self, path: Path):
+        self.custom_css.append(path.name)
+        shutil.copy(path, self.output_folder)
+
     def process_databases(self, database_id: str, property_filter: str, property_value: str):
         db = self._process_single_database(database_id, property_filter, property_value)
 
-        content = self.index_template.render(databases=[db], version=nprompter.__version__)
+        content = self.index_template.render(databases=[db], version=nprompter.__version__, custom_css=self.custom_css)
         with open(self.output_folder / "index.html", "w", encoding="utf8") as writeable:
             writeable.write(content)
 
@@ -50,7 +65,9 @@ class HtmlNotionProcessor:
         title_slug = slugify(title)
         blocks = self.notion_client.get_blocks(page["id"])
         block_contents = self.process_blocks(blocks)
-        content = self.script_template.render(elements=block_contents, title=title, version=nprompter.__version__)
+        content = self.script_template.render(
+            elements=block_contents, title=title, version=nprompter.__version__, custom_css=self.custom_css
+        )
 
         file_name = Path(self.output_folder, database_id, f"{title_slug}.html")
         with open(file_name, "w", encoding="utf8") as writeable:
@@ -97,6 +114,8 @@ class HtmlNotionProcessor:
                 expression = block["equation"]["expression"]
                 block_contents.append(f"<p>${expression}$</p>")
             else:
+                block_contents.append(f"<p>⚠ {block['type']} ⚠</p>")
+                block_contents.append(f"<!-- Block of type {block['type']} is not currently supported by Nprompter -->")
                 self.logger.warning(f"Block of type {block['type']} is not currently supported by Nprompter")
 
         return block_contents
@@ -106,9 +125,9 @@ class HtmlNotionProcessor:
         paragraph_content_tags = []
         for content in contents:
             if text := content.get("text"):
-                text_content = text["content"]
+                text_content = text["content"].replace("\n", "<br />")
                 annotations = content["annotations"]
-                annotations_tags = ["bold", "italic", "strikethrough", "underline"]
+                annotations_tags = ["bold", "italic", "strikethrough", "underline", "code"]
                 classes = " ".join([block_type] + [tag for tag in annotations_tags if annotations.get(tag)])
                 tag = f'<span class="{classes}">{text_content}</span>'
                 paragraph_content_tags.append(tag)
